@@ -915,13 +915,23 @@ class DeviceManager(Protocol):
 class CoreManager(Protocol):
     async def connect_to_plugin(self, plugin_name: str) -> "Optional[PluginInterface]": ...
     async def get_ffmpeg_path(self) -> str: ...
-    async def get_hwaccel_info(
-        self, target_codec: Union[Literal["h264"], Literal["h265"]], full_hardware: Optional[bool] = None
-    ) -> "FfmpegArgs": ...
+    async def get_hwaccel_info(self, options: Optional["HWAccelOptions"] = None) -> "FfmpegArgs": ...
     async def get_server_addresses(self) -> list[str]: ...
     async def get_ice_servers(self) -> list["IceServer"]: ...
 
 
+class HWAccelScale(TypedDict):
+    width: int
+    height: int
+
+
+class HWAccelOptions(TypedDict, total=False):
+    targetCodec: Union[Literal["h264"], Literal["h265"]]
+    keepOnHardware: bool
+    pixelFormat: str
+    scale: HWAccelScale
+
+
 class FfmpegArgs(TypedDict):
     codec: str
     hwaccel: str
@@ -929,6 +939,7 @@ class FfmpegArgs(TypedDict):
     hwaccelFilters: list[str]
     hwDeviceArgs: list[str]
     threads: str
+    supported: bool
 
 
 class IceServer(TypedDict):
